BaseCommand class abstract

Implementers

Constructors

BaseCommand()

Properties

description String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(ArgParser parser) → void
Override this to add custom options for each command
configureWithBase(ArgParser parser) → void
Internal: ensures --help is always added
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage(ArgParser parser) → void
run(ArgResults results) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited