CreateFeatureCommand class

Inheritance

Constructors

CreateFeatureCommand()

Properties

description String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure(ArgParser parser) → void
Override this to add custom options for each command
override
configureWithBase(ArgParser parser) → void
Internal: ensures --help is always added
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage(ArgParser parser) → void
inherited
run(ArgResults results) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited