Creators class

A utility class for creating directories and Dart files for a feature module in a Flutter project.

Constructors

Creators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createDataSources({required String path, required bool splitDataSource, required String featureName}) → void
createEntities({required String path, required List<String> models}) → void
createModels({required String path, required List<String> models}) → void
createPresentation({required String path, List<String>? widgets, List<String>? screens, required String featureName}) → void
createRepositories({required String path, required String featureName}) → void
createStateManagement({required String path, required String featureName, required String stateManagementType}) → void
createUseCases({required String path, required List<String> useCases, required String featureName}) → void