GlobalFlags mixin

Mixin to add and handle global flags for the CLI tool.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addGlobalFlags(ArgParser parser) → void
Adds global flags to the provided parser.
handleGlobalFlags(ArgResults results) → void
Handles the global flags based on the parsed results.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited