CLI class
Command-Line Interface (CLI) for the Next Feature tool. This tool helps in generating feature modules for Flutter applications.
- Mixed-in types
Constructors
- CLI()
- Initializes the CLI by adding global flags and registering commands.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addGlobalFlags(
ArgParser parser) → void -
Adds global flags to the provided
parser.inherited -
handleGlobalFlags(
ArgResults results) → void -
Handles the global flags based on the parsed
results.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> arguments) → void -
Runs the CLI with the provided
arguments. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited