FeatureGenerator class
A simple feature generator for a Flutter project
Constructors
Properties
- featureName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
models
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screens
→ List<
String> -
final
- splitDataSource → bool
-
final
- stateManagementType → String
-
final
- template → String
-
final
-
useCases
→ List<
String> -
final
Methods
-
generate(
) → void - Generates the feature structure based on the provided configuration
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited