Colors class
A utility class for ANSI color codes to colorize terminal output.
Constructors
- Colors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- black → const String
- blue → const String
- cyan → const String
- green → const String
- grey → const String
- lightBlue → const String
- lightCyan → const String
- lightGreen → const String
- lightGrey → const String
- lightMagenta → const String
- lightRed → const String
- lightYellow → const String
- magenta → const String
- red → const String
- reset → const String
- white → const String
- yellow → const String